Changelog
=========

0.0.8
-----

Changes:

- Unlimited lifetime added
- Custom lifetime added

0.0.7
-----

Changes:

- django 4.2 support added

0.0.6
-----

Changes:

- `MANIFEST.in` added
- `author_email` added

0.0.5
-----

Changes:

- `setup.py` fixed, templates folder added

0.0.4
-----

Changes:

- `setup.py` fixed, management command included in the dist build
- `docs` initiated

0.0.3
-----

Changes:

- `secure_links_nginx_location` management command improved.
- each location is being printed as part of nginx config file basing on public/private prefixes
- media location privacy level is being calculated and printed out
- config template moved outside the code into the `templates` folders

0.0.2
-----

Changes:

- README.rst code example fixed

0.0.1
-----

- Initial version released
